#ifndef NT2_INCLUDE_FUNCTIONS_NEGS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_NEGS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/negs.hpp>

#endif
